# SIMP Repository RPM

The SIMP Repository RPM is designed to provide all files necessary to install
SIMP via yum repos. This is achieved by creating and manging the SMIP repo
config files, creating SIMP Release yum variables, and adding the SIMP and
Puppet GPG Keys.

## SIMP Release Variables

By default, SIMP variables will be set for `simprelease` and `simpreleasetype`
matching the latest stable major release. These variables are set in files of
the same name in the /etc/yum/vars/ folder.

### simprelease

The `simprelease` variable is set by the `/etc/yum/vars/simprelease` file. This
file, by default is set to the lastest Major version of SIMP. This file should
be edited to reflect the Major(X), Minor(Y), or Patch(Z) release of SIMP you
want (Format: 'X', 'X.Y', 'X.Y.Z', or 'X.Y.Z-0').

Setting this file to a 'X' (ex: '6') will install the latest release for that
SIMP Major version and grab updates for all future releases in that Major
version of SIMP, including all minor and patch releases. Set this if you want
all SIMP Releases as they are tested and released. If you set this to '6', you
will receive all SIMP 6 releases, but never updated to '7' until the file is
changed.

Setting this file to 'X.Y'(ex: '6.4') will install the latest X.Y Release and
grab updates for all future patches to that X.Y version, but never update to
the next Minor version. Set this if you want a specific Minor version of SIMP,
but don't want to install new Minor versions. If you set this to '6.4', you
will receive all SIMP 6.4 patch updates, but never updated to '6.5' until the
file is changed.

Setting this file to 'X.Y.Z' or 'X.Y.Z-iteration' will install that specific
SIMP release and never grab any updates. Set this if you want only a specific
release of SIMP, and no future updates. If you set this to '6.4.0', you will
not receive any updates until the file is changed, unless you use the 'rolling'
release type (explained below).

### simpreleasetype

The `simpreleasetype` variable is set by the `/etc/yum/vars/simpreleasetype`
file. This file by default is set to 'releases'. This file should be edited to
reflect the type of SIMP releases you want. Valid types below:

* `releases`: Setting this file to 'releases' (Default) will only grab fully
  tested SIMP releases.

* `rolling`: Setting this file to 'rolling' will grab updates to RPMs that have
  not yet made it into a SIMP Release, but have been tested and released
  individually with confidence. This is an example where you can specify a
  specific SIMP release (ex: '6.4.0-0'), but still receive updates.

* 'unstable/simp6': Setting this file to 'unstable/simp6' will grab all updates
  to RPMs in the unstable repo (This is extremely dangerous and not recommended
  for production environments). This will also include 'unstable/simp7' in the
  future when SIMP 7 is released.

## RPM Notes

After install, the RPM will manage only the SIMP repo files, this README, and
the SIMP yum var files to avoid conflicts with other packages.

GPG Keys will remain on the system if the SIMP Repo RPM is uninstalled.

## Repo Notes

Repos will only work if you have the proper settings for variables.

The SIMP Enterprise repo is disabled by default. To enable it, edit the repo
file and change the value of `enabled` to `1`.

#### Examples

Setting '6' as the release will not allow you to install any SIMP 6.3 release,
as the latest SIMP 6 release is newer than 6.3. You would need to set '6.3' or
'6.3.0' as the release variable.

Setting the release or release type to an invalid version will not allow you to
access files. You can check valid releases at the URLs here:
  * releases:       https://download.simp-project.com/simp/yum/releases/
  * rolling:        https://download.simp-project.com/simp/yum/rolling/
  * unstable/simp6: https://download.simp-project.com/simp/yum/unstable/simp6/
